@@ -12,7 +12,7 @@ if (!isGeneric("merge")) {
 setMethod('merge', signature(x='Spatial', y='ANY'), 
   function(x, y, ...) {
 	y <- try(as.data.frame(y))
-	if (class(y) != 'data.frame') {
+	if (!inherits(y, 'data.frame')) {
 		stop('y cannot be coerced to a data.frame')
 	}
 	merge(x, y)
@@ -62,4 +62,4 @@ setMethod('merge', signature(x='Spatial', y='data.frame'),
 
 
 		
-		
\ No newline at end of file
+		
